@@ -71,6 +71,10 @@ def calcHairpin(seq, mv_conc=50.0, dv_conc=0.0, dntp_conc=0.8, dna_conc=50.0,
                 temp_c=37, max_loop=30):
     ''' Calculate the hairpin formation thermodynamics of a DNA sequence.
 
+    **Note that the maximum length of `seq` is 60 bp.** This is a cap suggested
+    by the Primer3 team as the longest reasonable sequence length for which
+    a two-state NN model produces reliable results (see primer3/src/libnano/thal.h:50).
+
     Args:
         seq (str): DNA sequence to analyze for hairpin formation
 
@@ -85,15 +89,23 @@ def calcHairpin(seq, mv_conc=50.0, dv_conc=0.0, dntp_conc=0.8, dna_conc=50.0,
         A `ThermoResult` object with thermodynamic characteristics of the
         hairpin formation.
 
+    Raises:
+        ``RuntimeError``
+
     '''
     _setThermoArgs(**locals())
-    return _THERMO_ANALYSIS.calcHairpin(seq)
+    return _THERMO_ANALYSIS.calcHairpin(seq).checkExc()
 
 
 def calcHomodimer(seq, mv_conc=50, dv_conc=0, dntp_conc=0.8, dna_conc=50,
                   temp_c=37, max_loop=30):
     ''' Calculate the homodimerization thermodynamics of a DNA sequence.
 
+    **Note that the maximum length of ``seq`` is 60 bp.** This is a cap imposed
+    by Primer3 as the longest reasonable sequence length for which
+    a two-state NN model produces reliable results (see 
+    primer3/src/libnano/thal.h:50).
+
     Args:
         seq (str)                       : DNA sequence to analyze for homodimer 
                                           formation calculations
@@ -110,15 +122,23 @@ def calcHomodimer(seq, mv_conc=50, dv_conc=0, dntp_conc=0.8, dna_conc=50,
         A `ThermoResult` object with thermodynamic characteristics of the
         homodimer interaction. 
 
+    Raises:
+        ``RuntimeError``
+
     '''
     _setThermoArgs(**locals())
-    return _THERMO_ANALYSIS.calcHomodimer(seq)
+    return _THERMO_ANALYSIS.calcHomodimer(seq).checkExc()
 
 
 def calcHeterodimer(seq1, seq2, mv_conc=50, dv_conc=0, dntp_conc=0.8,
                     dna_conc=50, temp_c=37, max_loop=30):
     ''' Calculate the heterodimerization thermodynamics of two DNA sequences.
 
+    **Note that at least one of the two sequences must by <60 bp in length.**
+    This is a cap imposed by Primer3 as the longest reasonable sequence length 
+    for which a two-state NN model produces reliable results (see
+    primer3/src/libnano/thal.h:50).
+
     Args:
         seq1 (str)              : First DNA sequence to analyze for heterodimer 
                                   formation
@@ -136,9 +156,12 @@ def calcHeterodimer(seq1, seq2, mv_conc=50, dv_conc=0, dntp_conc=0.8,
         A `ThermoResult` object with thermodynamic characteristics of the
         heterodimer interaction. 
 
+    Raises:
+        ``RuntimeError``
+
     '''
     _setThermoArgs(**locals())
-    return _THERMO_ANALYSIS.calcHeterodimer(seq1, seq2)
+    return _THERMO_ANALYSIS.calcHeterodimer(seq1, seq2).checkExc()
 
 
 def calcEndStability(seq1, seq2, mv_conc=50, dv_conc=0, dntp_conc=0.8,
@@ -146,6 +169,11 @@ def calcEndStability(seq1, seq2, mv_conc=50, dv_conc=0, dntp_conc=0.8,
     ''' Calculate the 3' end stability of DNA sequence `seq1` against DNA 
     sequence `seq2`.
 
+    **Note that at least one of the two sequences must by <60 bp in length.**
+    This is a cap imposed by Primer3 as the longest reasonable sequence length 
+    for which a two-state NN model produces reliable results (see
+    primer3/src/libnano/thal.h:50).
+
     Args:
         seq1 (str)                        : DNA sequence to analyze for 3' end
                                             hybridization against the target 
@@ -165,9 +193,12 @@ def calcEndStability(seq1, seq2, mv_conc=50, dv_conc=0, dntp_conc=0.8,
         A `ThermoResult` object with thermodynamic characteristics of the
         3' hybridization interaction. 
 
+    Raises:
+        ``RuntimeError``
+
     '''
     _setThermoArgs(**locals())
-    return _THERMO_ANALYSIS.calcEndStability(seq1, seq2)
+    return _THERMO_ANALYSIS.calcEndStability(seq1, seq2).checkExc()
 
 
 def calcTm(seq, mv_conc=50, dv_conc=0, dntp_conc=0.8, dna_conc=50,
@@ -175,6 +206,12 @@ def calcTm(seq, mv_conc=50, dv_conc=0, dntp_conc=0.8, dna_conc=50,
            salt_corrections_method='santalucia'):
     ''' Calculate the melting temperature (Tm) of a DNA sequence.
 
+    Note that NN thermodynamics will be used to calculate the Tm of sequences
+    up to 60 bp in length, after which point the following formula will be 
+    used::
+
+        Tm = 81.5 + 16.6(log10([mv_conc])) + 0.41(%GC) - 600/length
+
     Args:
         seq (str)                               : DNA sequence
 
